import{_ as b}from"./AbstraLogo.vue_vue_type_script_setup_true_lang.0dcd221d.js";import{C as h}from"./ContentLayout.ca05f4b2.js";import{l as k}from"./fetch.c1cb139b.js";import{d as w,e3 as g,e4 as v,f as C,c,w as s,o as i,b as p,a as x,u as d,d2 as _,az as m,Q as I}from"./index.fc2932f8.js";import{u as T,E as D}from"./editor.6808406f.js";import{C as L}from"./Card.6e42403c.js";import"./Logo.91831065.js";import"./userStore.7f6def7c.js";import"./workspaceStore.cf0c738c.js";import"./runnerData.595dcd96.js";import"./url.10dbde27.js";import"./colorHelpers.bebfdd8b.js";import"./linters.3e5f748d.js";import"./asyncComputed.011464f7.js";import"./TabPane.cf48df9d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="e8a90659-40ac-4d3a-95b4-fcf8f5250e1b",e._sentryDebugIdIdentifier="sentry-dbid-e8a90659-40ac-4d3a-95b4-fcf8f5250e1b")}catch{}})();const N={class:"card-content"},j=w({__name:"Welcome",setup(e){const t=g(),{query:n}=v(),a=T();a.loadLogin();const l=C(!0),u=async()=>{l.value=!1,setInterval(()=>{var o;return window.location.replace(((o=a==null?void 0:a.links)==null?void 0:o.project)||D.consoleUrl)},5e3)};return(async()=>{const o=n.token,r=n.redirect,f=await k("/_editor/auth/set-cookie",{method:"POST",body:JSON.stringify({token:o}),headers:{"Content-Type":"application/json"}});if(!f.ok)return u();const{ok:y}=await f.json();if(!y)return u();r?await t.push({path:r}):await t.push({name:"workspace"})})(),(o,r)=>(i(),c(h,null,{default:s(()=>[p(d(L),{bordered:!1,class:"card"},{default:s(()=>[x("div",N,[p(b,{style:{"margin-bottom":"10px"}}),l.value?(i(),c(d(_),{key:0},{default:s(()=>[m("Loading...")]),_:1})):(i(),c(d(_),{key:1},{default:s(()=>[m("Authentication failed. You are been redirected...")]),_:1}))])]),_:1})]),_:1}))}});const $=I(j,[["__scopeId","data-v-ba310460"]]);export{$ as default};
//# sourceMappingURL=Welcome.2eb86a5e.js.map
