import{C as d}from"./gateway.95c466eb.js";import"./index.fc2932f8.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[e]="705b396d-b8f9-4d55-9ed2-49cb70176bec",r._sentryDebugIdIdentifier="sentry-dbid-705b396d-b8f9-4d55-9ed2-49cb70176bec")}catch{}})();class a{async list(e){return d.get(`organizations/${e}/folders`)}async create(e){return d.post(`organizations/${e.organizationId}/folders`,{name:e.name,memberIds:e.memberIds})}async delete(e,n){return d.delete(`organizations/${e}/folders/${n}`)}async update(e,n){return d.patch(`organizations/${e}/folders/${n.id}/`,{name:n.name,memberIds:n.memberIds})}}export{a as F};
//# sourceMappingURL=folder.70badbf0.js.map
