import{d as t,o,K as s,b as d,u as r,br as _,Q as c}from"./index.fc2932f8.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="36abe68b-c626-4ba2-b0ab-22cee113ff5f",e._sentryDebugIdIdentifier="sentry-dbid-36abe68b-c626-4ba2-b0ab-22cee113ff5f")}catch{}})();const i={class:"centered"},f=t({__name:"LoadingContainer",setup(e){return(n,a)=>(o(),s("div",i,[d(r(_))]))}});const p=c(f,[["__scopeId","data-v-52e6209a"]]);export{p as L};
//# sourceMappingURL=LoadingContainer.757334c6.js.map
