import{P as g}from"./PlayerNavbar.abf6ab27.js";import{d as f,e3 as h,e4 as c,f as y,g as b,r as k,K as v,u as n,c as w,F as L,a as C,b as I,o as i,Q as N}from"./index.fc2932f8.js";import{u as V}from"./workspaceStore.cf0c738c.js";import"./userStore.7f6def7c.js";import"./metadata.972f4225.js";import"./PhWebhooksLogo.vue.3b6aaa79.js";import"./LoadingOutlined.7b1438ce.js";import"./PhSignOut.vue.f2d9b875.js";import"./index.5a6315cb.js";import"./Avatar.f75237ca.js";import"./runnerData.595dcd96.js";import"./url.10dbde27.js";import"./colorHelpers.bebfdd8b.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="e0c6c424-463e-4d42-9ea8-e881a5dbcd4a",o._sentryDebugIdIdentifier="sentry-dbid-e0c6c424-463e-4d42-9ea8-e881a5dbcd4a")}catch{}})();const x={class:"main-container"},B={class:"content"},D=f({__name:"Main",setup(o){const e=h(),t=V(),d=c().path,a=y(null),u=async({path:r,id:s})=>{a.value=s,await e.push({path:`/${r}`}),a.value=null},p=()=>{e.push({name:"playerLogin"})},l=()=>{e.push({name:"playerLogin"})},_=b(()=>!!c().meta.hideLogin);return(r,s)=>{const m=k("RouterView");return i(),v("div",x,[n(t).state.workspace?(i(),w(g,{key:0,"current-path":n(d),"hide-login":_.value,"runner-data":n(t).state.workspace,loading:a.value,onNavigate:u,onLoginClick:l,onLogoutClick:p},null,8,["current-path","hide-login","runner-data","loading"])):L("",!0),C("section",B,[I(m)])])}}});const A=N(D,[["__scopeId","data-v-f095bece"]]);export{A as default};
//# sourceMappingURL=Main.8467f42a.js.map
