import{_ as p}from"./TasksView.vue_vue_type_script_setup_true_lang.0f3af9ef.js";import{L as d}from"./tasksController.2eb55b1e.js";import{d as f,f as u,c as _,w as t,o as m,b as s,u as o,d6 as b,az as i,bM as y,da as k,Q as w}from"./index.fc2932f8.js";import{C as g}from"./ContentLayout.ca05f4b2.js";import{a as T}from"./ant-design.9eefec5b.js";import"./AbstraButton.vue_vue_type_script_setup_true_lang.e9703318.js";import"./PhCopy.vue.cf4eda27.js";import"./metadata.972f4225.js";import"./PhWebhooksLogo.vue.3b6aaa79.js";import"./string.bba51802.js";import"./index.9e263c02.js";import"./dayjs.7a8887c0.js";import"./gateway.95c466eb.js";import"./popupNotifcation.ca0d7c69.js";import"./linters.3e5f748d.js";import"./asyncComputed.011464f7.js";import"./scripts.96abd849.js";import"./record.04f0d9bc.js";import"./polling.548a5a79.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="9c29b70b-5201-45dc-a23c-c67a33b9b11e",e._sentryDebugIdIdentifier="sentry-dbid-9c29b70b-5201-45dc-a23c-c67a33b9b11e")}catch{}})();const x=f({__name:"Tasks",setup(e){const a=new d,r=u(null);async function l(){var n;await T("Are you sure you want to clear all tasks and their associated payloads?")&&await((n=r.value)==null?void 0:n.clearAllTasks())}return(c,n)=>(m(),_(g,null,{default:t(()=>[s(o(k),{justify:"space-between",align:"center"},{default:t(()=>[s(o(b),null,{default:t(()=>[i("Tasks")]),_:1}),s(o(y),{type:"link",style:{"margin-top":"10px"},onClick:l},{default:t(()=>[i("Clear all")]),_:1})]),_:1}),s(p,{ref_key:"tasksTableView",ref:r,class:"tasks",api:o(a),stages:null,editor:""},null,8,["api"])]),_:1}))}});const G=w(x,[["__scopeId","data-v-4b92e2a9"]]);export{G as default};
//# sourceMappingURL=Tasks.a14c984b.js.map
