import{P as r}from"./record.04f0d9bc.js";import{e as f,f as u}from"./index.fc2932f8.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="d46a9189-a611-4618-a915-75b2caba2efc",e._sentryDebugIdIdentifier="sentry-dbid-d46a9189-a611-4618-a915-75b2caba2efc")}catch{}})();const i=new r,b=f("omniChat",()=>{const e=u(!1),t=u(!1),n=()=>{t.value=!0},s=()=>{t.value=!1},o=()=>{e.value=!0,n()},a=()=>{e.value=!1,s()};return{isOpen:e,isInputFocused:t,focusInput:n,blurInput:s,open:o,close:a,toggle:()=>{e.value?a():o()}}});export{i as o,b as u};
//# sourceMappingURL=omniChatStore.e7dda237.js.map
