import{d as n,K as s,a as d,O as a,ec as r,o as l,Q as c}from"./index.fc2932f8.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="834a6957-d903-4e6c-87db-f0e20fb1c815",e._sentryDebugIdIdentifier="sentry-dbid-834a6957-d903-4e6c-87db-f0e20fb1c815")}catch{}})();const _={class:"content-layout"},u=n({__name:"ContentLayout",props:{fullWidth:{type:Boolean}},setup(e){return(t,o)=>(l(),s("div",_,[d("div",{class:r(["centered-layout",{"full-width":t.fullWidth}])},[a(t.$slots,"default",{},void 0,!0)],2)]))}});const i=c(u,[["__scopeId","data-v-6397d501"]]);export{i as C};
//# sourceMappingURL=ContentLayout.ca05f4b2.js.map
