import{B as e}from"./BaseLayout.ed92920f.js";import{d as a,e4 as n,r as s,c,w as r,o as d,b as i,u}from"./index.fc2932f8.js";import{N as f,_}from"./Navbar.b9ca9351.js";import"./OmniChat.273b6880.js";import"./gateway.95c466eb.js";import"./popupNotifcation.ca0d7c69.js";import"./AbstraLogo.vue_vue_type_script_setup_true_lang.0dcd221d.js";import"./Logo.91831065.js";import"./uuid.7ef9c0b4.js";import"./PhCopy.vue.cf4eda27.js";import"./PhClockCounterClockwise.vue.3c149af0.js";import"./omniChatStore.e7dda237.js";import"./record.04f0d9bc.js";import"./LoadingOutlined.7b1438ce.js";import"./columns.92249f00.js";import"./string.bba51802.js";import"./linters.3e5f748d.js";import"./asyncComputed.011464f7.js";import"./controller.2ede86e6.js";import"./workspaces.64dd1c59.js";import"./runnerData.595dcd96.js";import"./url.10dbde27.js";import"./colorHelpers.bebfdd8b.js";import"./index.4bc42d3f.js";import"./validations.6fdb4823.js";import"./metadata.972f4225.js";import"./PhWebhooksLogo.vue.3b6aaa79.js";import"./controller.0287b007.js";import"./fetch.c1cb139b.js";import"./PhPencil.vue.fca5b514.js";import"./project.46a15226.js";import"./requirements.1a448824.js";import"./object.8d980c69.js";import"./scripts.96abd849.js";import"./PhCopySimple.vue.5ea40acc.js";import"./index.1c04d224.js";import"./CollapsePanel.351e5f6c.js";import"./Avatar.f75237ca.js";import"./AbstraButton.vue_vue_type_script_setup_true_lang.e9703318.js";import"./PhArrowCounterClockwise.vue.f15964a7.js";import"./PhFilePy.vue.8ed86f23.js";import"./PhChats.vue.0b21e3fd.js";import"./PhRocket.vue.67a61b26.js";import"./PhPackage.vue.3198e426.js";import"./userStore.7f6def7c.js";import"./polling.548a5a79.js";import"./PhArrowSquareOut.vue.740ddb4d.js";import"./PhDotsThree.vue.8b36a8fb.js";import"./PhSignOut.vue.f2d9b875.js";import"./PhSparkle.vue.d0615af5.js";import"./editor.6808406f.js";import"./workspaceStore.cf0c738c.js";import"./index.ce43c581.js";import"./CloseCircleOutlined.a890340d.js";import"./CheckCircleFilled.5b382897.js";import"./index.18af8dc7.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[o]="dad436e8-18a3-47cb-a9e9-cb2651495b46",t._sentryDebugIdIdentifier="sentry-dbid-dad436e8-18a3-47cb-a9e9-cb2651495b46")}catch{}})();const wt=a({__name:"Workspace",setup(t){const o=n();return(p,l)=>{const m=s("RouterView");return d(),c(e,null,{navbar:r(()=>[i(f,{"page-title":u(o).meta.title},null,8,["page-title"])]),content:r(()=>[i(m)]),chat:r(()=>[i(_)]),_:1})}}});export{wt as default};
//# sourceMappingURL=Workspace.638748fe.js.map
