import{d as i,c as p,w as n,o as m,b as a,u as t}from"./index.fc2932f8.js";import"./linters.3e5f748d.js";import{W as s}from"./workspaces.64dd1c59.js";import{C as d}from"./ContentLayout.ca05f4b2.js";import{E as f}from"./controller.0287b007.js";import{_ as c}from"./View.vue_vue_type_script_setup_true_lang.1ab26c33.js";import"./asyncComputed.011464f7.js";import"./runnerData.595dcd96.js";import"./url.10dbde27.js";import"./colorHelpers.bebfdd8b.js";import"./record.04f0d9bc.js";import"./gateway.95c466eb.js";import"./popupNotifcation.ca0d7c69.js";import"./fetch.c1cb139b.js";import"./PhPencil.vue.fca5b514.js";import"./SaveButton.7bcd260d.js";import"./UnsavedChangesHandler.920aaf77.js";import"./ExclamationCircleOutlined.f6290854.js";import"./CrudView.b9a524be.js";import"./router.1cd98f72.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.a21ba738.js";import"./PhDotsThreeVertical.vue.692a5e4b.js";import"./Badge.11b9a826.js";import"./index.ce43c581.js";import"./index.9e263c02.js";import"./polling.548a5a79.js";import"./omniChatStore.e7dda237.js";import"./index.18af8dc7.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="e1984a01-59ef-40b3-9bb1-469b4a7135ce",o._sentryDebugIdIdentifier="sentry-dbid-e1984a01-59ef-40b3-9bb1-469b4a7135ce")}catch{}})();const H=i({__name:"EnvVarsEditor",setup(o){const r=new f;return(e,u)=>(m(),p(d,null,{default:n(()=>[a(c,{"env-var-repository":t(r),mode:"editor","file-opener":t(s)},null,8,["env-var-repository","file-opener"])]),_:1}))}});export{H as default};
//# sourceMappingURL=EnvVarsEditor.55c24425.js.map
