import{C as t,E as i,K as b,a as d,M as c,c as l,P as y,R as f,S as g,b as u,T as k,U as p,e as w,l as D}from"./toggleHighContrast.87b534e3.js";import"./index.fc2932f8.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="c95ab5aa-b7ce-4bc8-ad4e-bebe1eeb36e1",e._sentryDebugIdIdentifier="sentry-dbid-c95ab5aa-b7ce-4bc8-ad4e-bebe1eeb36e1")}catch{}})();export{t as CancellationTokenSource,i as Emitter,b as KeyCode,d as KeyMod,c as MarkerSeverity,l as MarkerTag,y as Position,f as Range,g as Selection,u as SelectionDirection,k as Token,p as Uri,w as editor,D as languages};
//# sourceMappingURL=editor.main.51d00563.js.map
