import{C as p}from"./controller.0287b007.js";import{d as i,e4 as n,c as s,u as m,o as a}from"./index.fc2932f8.js";import{_ as d}from"./View.vue_vue_type_script_setup_true_lang.1ab26c33.js";import"./gateway.95c466eb.js";import"./popupNotifcation.ca0d7c69.js";import"./fetch.c1cb139b.js";import"./record.04f0d9bc.js";import"./PhPencil.vue.fca5b514.js";import"./SaveButton.7bcd260d.js";import"./UnsavedChangesHandler.920aaf77.js";import"./ExclamationCircleOutlined.f6290854.js";import"./CrudView.b9a524be.js";import"./router.1cd98f72.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.a21ba738.js";import"./url.10dbde27.js";import"./PhDotsThreeVertical.vue.692a5e4b.js";import"./Badge.11b9a826.js";import"./index.ce43c581.js";import"./index.9e263c02.js";import"./asyncComputed.011464f7.js";import"./polling.548a5a79.js";import"./omniChatStore.e7dda237.js";import"./index.18af8dc7.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="f298abb0-5855-486f-8b40-62097b8c055d",o._sentryDebugIdIdentifier="sentry-dbid-f298abb0-5855-486f-8b40-62097b8c055d")}catch{}})();const F=i({__name:"EnvVars",setup(o){const t=n().params.projectId,e=new p(t);return(c,f)=>(a(),s(d,{"env-var-repository":m(e),mode:"console"},null,8,["env-var-repository"]))}});export{F as default};
//# sourceMappingURL=EnvVars.473db71a.js.map
