import{O as r}from"./userStore.7f6def7c.js";import{d as l,J as i,K as u,b as a,w as n,u as d,o as c,az as o,d6 as f,d5 as b}from"./index.fc2932f8.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="b8dbc079-da01-4da0-b1e6-e4e5d7499525",e._sentryDebugIdIdentifier="sentry-dbid-b8dbc079-da01-4da0-b1e6-e4e5d7499525")}catch{}})();const p=l({__name:"OidcLoginCallback",setup(e){return i(async()=>{await new r().loginCallback()}),(t,s)=>(c(),u("div",null,[a(d(f),null,{default:n(()=>[o("You're authenticated")]),_:1}),a(d(b),null,{default:n(()=>[o(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{p as default};
//# sourceMappingURL=OidcLoginCallback.f5b20b65.js.map
