import{_ as l}from"./Login.vue_vue_type_script_setup_true_lang.c8631ff0.js";import{d as m,e3 as f,e4 as b,K as g,b as y,u as n,o as w,Q as k}from"./index.fc2932f8.js";import{u as h}from"./workspaceStore.cf0c738c.js";import"./userStore.7f6def7c.js";import"./CircularLoading.8b573451.js";import"./Logo.91831065.js";import"./string.bba51802.js";import"./index.18af8dc7.js";import"./runnerData.595dcd96.js";import"./url.10dbde27.js";import"./colorHelpers.bebfdd8b.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="288eb80d-49e1-4b32-add7-cd3d821dd19c",e._sentryDebugIdIdentifier="sentry-dbid-288eb80d-49e1-4b32-add7-cd3d821dd19c")}catch{}})();const v={class:"runner"},I=m({__name:"Login",setup(e){const o=f(),t=b(),r=h(),_=async()=>{const{redirect:s,...a}=t.query;if(s){await o.push({path:s,query:a,params:t.params});return}o.push({name:"playerHome",query:a})};return(s,a)=>{var d,c,p,u,i;return w(),g("div",v,[y(l,{"logo-url":(c=(d=n(r).state.workspace)==null?void 0:d.logoUrl)!=null?c:void 0,"brand-name":(p=n(r).state.workspace)==null?void 0:p.brandName,locale:(i=(u=n(r).state.workspace)==null?void 0:u.language)!=null?i:"en",onDone:_},null,8,["logo-url","brand-name","locale"])])}}});const K=k(I,[["__scopeId","data-v-cb33c596"]]);export{K as default};
//# sourceMappingURL=Login.a1d34577.js.map
