import{L as t}from"./Logo.91831065.js";import{d as n,o as r,c as d,u as i}from"./index.fc2932f8.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="efa3e6e9-9a7f-440a-b166-6aa1ba1a8775",e._sentryDebugIdIdentifier="sentry-dbid-efa3e6e9-9a7f-440a-b166-6aa1ba1a8775")}catch{}})();const f="/assets/logo.0faadfa2.svg",b=n({__name:"AbstraLogo",props:{hideText:{type:Boolean},size:{}},setup(e){return(a,o)=>{var s;return r(),d(t,{"image-url":i(f),"brand-name":"Abstra","hide-text":a.hideText,size:(s=a.size)!=null?s:"small"},null,8,["image-url","hide-text","size"])}}});export{b as _};
//# sourceMappingURL=AbstraLogo.vue_vue_type_script_setup_true_lang.0dcd221d.js.map
