import{A as o}from"./index.ab0cff68.js";import{d as r,g as a,K as p,b as c,u as f,ec as l,F as d,o as i,Q as u}from"./index.fc2932f8.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="9f111c63-75b5-4f7e-b623-0c404354cedb",e._sentryDebugIdIdentifier="sentry-dbid-9f111c63-75b5-4f7e-b623-0c404354cedb")}catch{}})();const _=r({__name:"Steps",props:{stepsInfo:{},isPreview:{type:Boolean}},setup(e){const s=e,n=a(()=>s.stepsInfo?Array(s.stepsInfo.total).fill(null).map(()=>({label:"",description:""})):[]);return(t,b)=>t.stepsInfo?(i(),p("nav",{key:0,class:l(["p-steps",{"full-screen":!t.isPreview}])},[c(f(o),{current:t.stepsInfo.current-1,items:n.value,responsive:!1},null,8,["current","items"])],2)):d("",!0)}});const I=u(_,[["__scopeId","data-v-8b0ea4f1"]]);export{I as S};
//# sourceMappingURL=Steps.777a3e63.js.map
