import{m as a,n,T as r,p as o,P as p,C as d,M as c,s as f,q as s,t as m,v as u,x as b,y as g}from"./index.fc2932f8.js";import{s as y}from"./userStore.7f6def7c.js";import{_ as l}from"./App.vue_vue_type_style_index_0_lang.ad2d4850.js";import{a as i}from"./workspaceStore.cf0c738c.js";import"./PlayerConfigProvider.026acba3.js";import"./colorHelpers.bebfdd8b.js";import"./index.9b731567.js";import"./runnerData.595dcd96.js";import"./url.10dbde27.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="b26a7852-4f53-43bf-ad14-58b4042589c7",t._sentryDebugIdIdentifier="sentry-dbid-b26a7852-4f53-43bf-ad14-58b4042589c7")}catch{}})();class w{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await y();const t=a(),e=n({render:()=>m(l)});r.init(),o(e,i),w.init(),e.use(i),e.use(t),e.use(p),e.mount("#app"),e.component("VSelect",d),e.component("Markdown",c),e.component("Message",f),s(e,u),s(e,b),s(e,g)})();
//# sourceMappingURL=player.82d681b3.js.map
