import{_ as m}from"./TasksView.vue_vue_type_script_setup_true_lang.0f3af9ef.js";import{R as f}from"./tasksController.2eb55b1e.js";import{d as _,e4 as g,g as y,K as b,b as w,w as k,u as n,c as I,F as T,aL as v,o as c,az as B,d6 as j}from"./index.fc2932f8.js";import"./gateway.95c466eb.js";import{a as x,B as C}from"./build.b2eb3f75.js";import{P as D}from"./project.46a15226.js";import"./columns.92249f00.js";import{a as R}from"./asyncComputed.011464f7.js";import"./AbstraButton.vue_vue_type_script_setup_true_lang.e9703318.js";import"./PhCopy.vue.cf4eda27.js";import"./metadata.972f4225.js";import"./PhWebhooksLogo.vue.3b6aaa79.js";import"./ant-design.9eefec5b.js";import"./string.bba51802.js";import"./index.9e263c02.js";import"./dayjs.7a8887c0.js";import"./linters.3e5f748d.js";import"./scripts.96abd849.js";import"./record.04f0d9bc.js";import"./polling.548a5a79.js";import"./popupNotifcation.ca0d7c69.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="97936a54-f157-465f-afcd-c21ffe2c427c",e._sentryDebugIdIdentifier="sentry-dbid-97936a54-f157-465f-afcd-c21ffe2c427c")}catch{}})();const X=_({__name:"Tasks",setup(e){const a=g().params.projectId,l=new f(a),{result:o}=R(async()=>{const r=(await x.list(a)).find(d=>d.latest);if(!r)return null;const[p,u]=await Promise.all([C.get(r.id),D.get(a)]);return{buildSpec:p,project:u}}),i=y(()=>!o.value||!o.value.buildSpec?null:o.value.buildSpec.runtimes.map(t=>({id:t.id,stageTitle:t.title,stageType:t.type})));return(t,r)=>(c(),b(v,null,[w(n(j),null,{default:k(()=>[B("Tasks")]),_:1}),i.value?(c(),I(m,{key:0,class:"tasks",api:n(l),stages:i.value},null,8,["api","stages"])):T("",!0)],64))}});export{X as default};
//# sourceMappingURL=Tasks.10ff9296.js.map
